==> huaweicloudsdkcodehub-3.1.64-py2.py3-none-any.whl: huaweicloudsdkcodehub/v3/model/show_merge_request_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowMergeRequestRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'repository_id': 'int',
        'merge_request_id': 'int'
    }

    attribute_map = {
        'repository_id': 'repository_id',
        'merge_request_id': 'merge_request_id'
    }

    def __init__(self, repository_id=None, merge_request_id=None):
        """ShowMergeRequestRequest

        The model defined in huaweicloud sdk

        :param repository_id: 仓库短id
        :type repository_id: int
        :param merge_request_id: 合并请求id
        :type merge_request_id: int
        """
        
        

        self._repository_id = None
        self._merge_request_id = None
        self.discriminator = None

        self.repository_id = repository_id
        self.merge_request_id = merge_request_id

    @property
    def repository_id(self):
        """Gets the repository_id of this ShowMergeRequestRequest.

        仓库短id

        :return: The repository_id of this ShowMergeRequestRequest.
        :rtype: int
        """
        return self._repository_id

    @repository_id.setter
    def repository_id(self, repository_id):
        """Sets the repository_id of this ShowMergeRequestRequest.

        仓库短id

        :param repository_id: The repository_id of this ShowMergeRequestRequest.
        :type repository_id: int
        """
        self._repository_id = repository_id

    @property
    def merge_request_id(self):
        """Gets the merge_request_id of this ShowMergeRequestRequest.

        合并请求id

        :return: The merge_request_id of this ShowMergeRequestRequest.
        :rtype: int
        """
        return self._merge_request_id

    @merge_request_id.setter
    def merge_request_id(self, merge_request_id):
        """Sets the merge_request_id of this ShowMergeRequestRequest.

        合并请求id

        :param merge_request_id: The merge_request_id of this ShowMergeRequestRequest.
        :type merge_request_id: int
        """
        self._merge_request_id = merge_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowMergeRequestRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcodehub-3.1.152-py2.py3-none-any.whl: huaweicloudsdkcodehub/v3/model/show_merge_request_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowMergeRequestRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'repository_id': 'int',
        'merge_request_id': 'int'
    }

    attribute_map = {
        'repository_id': 'repository_id',
        'merge_request_id': 'merge_request_id'
    }

    def __init__(self, repository_id=None, merge_request_id=None):
        r"""ShowMergeRequestRequest

        The model defined in huaweicloud sdk

        :param repository_id: 仓库短id
        :type repository_id: int
        :param merge_request_id: 合并请求id
        :type merge_request_id: int
        """
        
        

        self._repository_id = None
        self._merge_request_id = None
        self.discriminator = None

        self.repository_id = repository_id
        self.merge_request_id = merge_request_id

    @property
    def repository_id(self):
        r"""Gets the repository_id of this ShowMergeRequestRequest.

        仓库短id

        :return: The repository_id of this ShowMergeRequestRequest.
        :rtype: int
        """
        return self._repository_id

    @repository_id.setter
    def repository_id(self, repository_id):
        r"""Sets the repository_id of this ShowMergeRequestRequest.

        仓库短id

        :param repository_id: The repository_id of this ShowMergeRequestRequest.
        :type repository_id: int
        """
        self._repository_id = repository_id

    @property
    def merge_request_id(self):
        r"""Gets the merge_request_id of this ShowMergeRequestRequest.

        合并请求id

        :return: The merge_request_id of this ShowMergeRequestRequest.
        :rtype: int
        """
        return self._merge_request_id

    @merge_request_id.setter
    def merge_request_id(self, merge_request_id):
        r"""Sets the merge_request_id of this ShowMergeRequestRequest.

        合并请求id

        :param merge_request_id: The merge_request_id of this ShowMergeRequestRequest.
        :type merge_request_id: int
        """
        self._merge_request_id = merge_request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowMergeRequestRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
